@@ -1,4 +1,5 @@
 import os
+import sys
 
 def main(name):
     print("Creating app...")
@@ -12,4 +13,10 @@ def main(name):
         print("created index...")
     with open(f"{name}/index.css", "w") as f:
         f.write(open("templates/index.css", "r").read())
-        print("created index.css...")
\ No newline at end of file
+        print("created index.css...")
+
+try:
+    if sys.argv[1] == "--new" or "-n":
+        main(sys.argv[2])
+except IndexError:
+    print("Usage: spinne --new <name>")
\ No newline at end of file
